*******************************
Ex Memoriam
*******************************

.. image:: https://img.shields.io/pypi/v/exmemo.svg
   :target: https://pypi.python.org/pypi/exmemo

.. image:: https://img.shields.io/pypi/pyversions/exmemo.svg
   :target: https://pypi.python.org/pypi/exmemo

.. image:: https://img.shields.io/travis/kalekundert/exmemo.svg
   :target: https://travis-ci.org/kalekundert/exmemo

.. image:: https://img.shields.io/coveralls/kalekundert/exmemo.svg
   :target: https://coveralls.io/github/kalekundert/exmemo?branch=master

Installation
============
Coming soon...

Usage
=====
Coming soon...
